@@ -29,6 +29,7 @@ import os.path
 import re
 import string
 import sys
+import warnings
 
 from turberfield.dialogue.directives import Condition as ConditionDirective
 from turberfield.dialogue.directives import Entity as EntityDirective
@@ -186,7 +187,7 @@ class Model(docutils.nodes.GenericNodeVisitor):
         ))
 
     def visit_Evaluation(self, node):
-        ref, attr = node["arguments"][0].split(".")
+        ref, dot, attr = node["arguments"][0].partition(".")
         entity = self.get_entity(ref)
         s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
         try:
