@@ -319,7 +319,7 @@ class ConditionDirectiveTests(unittest.TestCase):
 
         Outside.
 
-        Summary
+        Intense
         -------
 
         .. condition:: WEATHER.state
@@ -329,6 +329,15 @@ class ConditionDirectiveTests(unittest.TestCase):
 
             It's stormy!
 
+        Hushed
+        ------
+
+        .. condition:: WEATHER.state.name quiet
+
+        [WEATHER]_
+
+            It's quiet.
+
         Snow storm
         ----------
 
